==> u61-0.3.1.tar.gz: u61-0.3.1/src/networkoptionmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   networkoptionmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: this menu lets the user set up some network parameters.
 *              These parameters are rather "advandced parameters" and most
 *              of them should never be changed, except when tweaking u61
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "networkoptionmenu.h"
#include "number.h"
#include "edit.h"
#include "editnumber.h"
#include "toggle.h"
#include "config.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the network option menu
 */ 
U61_NetworkOptionMenu::U61_NetworkOptionMenu(U61_Menu *parent,
					     U61_Config *conf)
  : U61_Menu(parent,"Network settings")
{
  config=conf;
  add_item(new U61_Edit("Server",conf->server_id));
  add_item(new U61_Toggle("Anticipation mode is",&(conf->network_anticipation),
                            "on","off"));
  add_item(new U61_EditNumber("TCP/IP port",
			      &(conf->network_port),1000,10000));
  add_item(new U61_EditNumber("ClanLib channel",
			      &(conf->network_channel),0,255));
           
  select(0);
}

==> u61-1.0.1.tar.gz: u61-1.0.1/src/networkoptionmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   networkoptionmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: this menu lets the user set up some network parameters.
 *              These parameters are rather "advandced parameters" and most
 *              of them should never be changed, except when tweaking u61
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "networkoptionmenu.h"
#include "number.h"
#include "editaddress.h"
#include "editnumber.h"
#include "toggle.h"
#include "config.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the network option menu
 */ 
U61_NetworkOptionMenu::U61_NetworkOptionMenu(U61_Menu *parent,
					     U61_Config *conf)
  : U61_Menu(parent,"Network settings")
{
  config=conf;
  add_item(new U61_EditAddress("Server",conf->server_id));
  add_item(new U61_Toggle("Anticipation mode is",&(conf->network_anticipation),
                            "on","off"));
  add_item(new U61_EditNumber("TCP/IP port",
			      &(conf->network_port),1000,10000));
  add_item(new U61_EditNumber("ClanLib channel",
			      &(conf->network_channel),0,255));
           
  select(0);
}
